matplotlib_inline: Inline Matplotlib backend for Jupyter
========================================================

Description
-----------

Inline Matplotlib backend for Jupyter

License
-------

BSD 3-Clause

Upstream Contact
----------------

https://pypi.org/project/matplotlib-inline/

